==> tailor-0.3.0.tgz: package/README.md <==
# Tailor

Tailor is a developer tool that simplifies inspecting spacings on websites. While holding the toggle key (Alt or option), hover around the page to inspect elements. Size, margin, and padding will be highlighted, and font information will be displayed in the panel.

While Tailor is active, you can also click on an element to lock it and enter the measuring mode. Now, Tailor will display the distance between the locked element and any other element you hover over.

Try it yourself - https://muffinman.io/tailor/

Desktop only.

Our QA team does extensive checks to ensure that spacings, paddings, and font sizes match the designs. I created this library/extension hoping to make their lives easier.

## Extensions

<a href="https://addons.mozilla.org/en-US/firefox/addon/tailor/"><img style="height: 70px" src="./docs/img/ff.png"></a>
<a href="https://chromewebstore.google.com/detail/hpnihgcmhjlfpniefhkpadfepbnnjfcm"><img style="height: 70px" src="./docs/img/chrome.png"></a>

Chrome extension is still under review and should be available soon.

## Setup

- Use node version from `.nvmrc` - `nvm use`
- Install dependencies `npm install`

## Development server

- Start a simple development - `npm start`
- Open http://localhost:8000/

## Extension

### Firefox

Project uses [web-ext](https://github.com/mozilla/web-ext) for Firefox extension development.

- Start extension in development mode - `npm run firefox:run`
- Build Firefox extension in development mode - `npm run firefox:run`

### Chrome

Work in progress. For now you can copy `manifest-chrome.json` to `manifest.json` and load unpacked extension.

## TODO

- [ ] Info panel improvements
- [ ] When parent is scrolled calculated position is wrong, probably need to subtract the scroll position
- [ ] Handle touch events when simulating phones/tablets in devtools

==> tailor-0.3.1.tgz: package/README.md <==
# Tailor

Tailor is a developer tool that simplifies inspecting spacings on websites. While holding the toggle key (Alt or option), hover around the page to inspect elements. Size, margin, and padding will be highlighted, and font information will be displayed in the panel.

While Tailor is active, you can also click on an element to lock it and enter the measuring mode. Now, Tailor will display the distance between the locked element and any other element you hover over.

Try it yourself - https://muffinman.io/tailor/

Desktop only.

Our QA team does extensive checks to ensure that spacings, paddings, and font sizes match the designs. I created this library/extension hoping to make their lives easier.

## Extensions

<a href="https://addons.mozilla.org/en-US/firefox/addon/tailor/"><img style="height: 70px" src="./docs/img/ff.png"></a>
<a href="https://chromewebstore.google.com/detail/hpnihgcmhjlfpniefhkpadfepbnnjfcm"><img style="height: 70px" src="./docs/img/chrome.png"></a>

Chrome extension is still under review and should be available soon.

## Library

## Bookmarklet

You can also load Tailor using this bookmarklet. But be aware that depending on a site's security policies it may not load.

```js
javascript: void (async function () {
  const Tailor = await import("https://esm.sh/@stanko/tailor");
  new Tailor.default();
  const style = document.createElement("link");
  style.setAttribute("href", "https://esm.sh/@stanko/tailor/dist/tailor.css");
  style.setAttribute("rel", "stylesheet");
  document.head.append(style);
})();
```

## Setup

- Use node version from `.nvmrc` - `nvm use`
- Install dependencies - `npm install`
- Copy git hooks - `sh ./tools/copy-hooks.sh`

## Development server

- Start a simple development - `npm start`
- Open http://localhost:8000/

## Extension

### Firefox

Project uses [web-ext](https://github.com/mozilla/web-ext) for Firefox extension development.

- Start extension in development mode - `npm run firefox:run`
- Build Firefox extension - `npm run firefox:run`

### Chrome

- For now, copy `manifest-chrome.json` to `manifest.json` and load the unpacked extension
- Build Chrome extension - `npm run chrome:run`

## TODO

- [ ] Info panel improvements
- [ ] When parent is scrolled calculated position is wrong, probably need to subtract the scroll position
- [ ] Handle touch events when simulating phones/tablets in devtools
